==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-cpuload/cpuload_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation>Carico del processore %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="124"/>
        <source>CPU load %1%</source>
        <translation>Carico del processore %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation>Impostazioni del carico del processore di LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Impostazioni del carico del processore</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Mostra testo</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervallo di aggiornamento:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientamento della barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Larghezza barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Bottom up</source>
        <translation>Dal basso all&apos;alto</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Top down</source>
        <translation>Dall&apos;alto al basso</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="72"/>
        <source>Left to right</source>
        <translation>Da sinistra a destra</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="73"/>
        <source>Right to left</source>
        <translation>Da destra a sinistra</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-cpuload/cpuload_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation type="vanished">Carico del processore %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>Carico del processore %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation type="vanished">Impostazioni del carico del processore di LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Impostazioni del carico del processore</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Mostra testo</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervallo di aggiornamento:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientamento della barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Larghezza barra:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Dal basso all&apos;alto</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Dall&apos;alto al basso</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Da sinistra a destra</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Da destra a sinistra</translation>
    </message>
</context>
</TS>
